==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/api/apirtroute/formatterlegs/leg_format_trip.go <==
package formatterlegs

import (
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
)

func FormatConnectionsToLegTrip(
	yyyymmdd uint,
	timezoneUTCDeltasecs int,
	legConnections []*dbt.ConnectionVerbose,
) *RouteLeg {
	var (
		connectionFrom = legConnections[0]
		connectionTo   = legConnections[len(legConnections)-1]
		timeFrom       = utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, connectionFrom.FromStopDRUTCTime)
		timeTo         = utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, connectionTo.ToStopDRUTCTime)
	)
	return &RouteLeg{
		LegType:           "trip",
		LegDuration:       timeTo.Sub(timeFrom).String(),
		LegFromCoords:     [2]float64{connectionFrom.FromStopLat, connectionFrom.FromStopLon},
		LegToCoords:       [2]float64{connectionTo.ToStopLat, connectionTo.ToStopLon},
		LegBeginTime:      timeFrom,
		LegEndTime:        timeTo,
		TripRouteHeadsign: connectionFrom.TripHeadsign,
		TripRoute:         coalesce(connectionFrom.RouteShortName, connectionFrom.RouteLongName),
		TripFrom:          &connectionFrom.FromStopName,
		TripFromSIDU:      &connectionFrom.FromStopSIDU,
		TripTo:            &connectionTo.ToStopName,
		TripToSIDU:        &connectionTo.ToStopSIDU,
		TripAgencyID:      connectionTo.AgencyID,
		TripFeedID:        &connectionTo.FeedID,
		TripStops:         ptr(FormatLegsStopDetails(yyyymmdd, timezoneUTCDeltasecs, legConnections)),
	}
}

func FormatLegsStopDetails(
	yyyymmdd uint,
	timezoneUTCDeltasecs int,
	legConnections []*dbt.ConnectionVerbose,
) []*RouteStopDetails {
	m := []*RouteStopDetails{}
	for j, c := range legConnections {
		m = append(m, &RouteStopDetails{
			Time:   utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, c.FromStopDRUTCTime),
			Name:   c.FromStopName,
			Coords: [2]float64{c.FromStopLat, c.FromStopLon},
			ConnID: c.ConnID,
		})
		if j == len(legConnections)-1 {
			m = append(m, &RouteStopDetails{
				Time:   utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, c.ToStopDRUTCTime),
				Name:   c.ToStopName,
				Coords: [2]float64{c.ToStopLat, c.ToStopLon},
				ConnID: c.ConnID,
			})
		}
	}
	return m
}

==> mobroute-0.9.0.tar.gz: mobroute-v0.9.0/api/apirtroute/formatterlegs/leg_format_trip.go <==
package formatterlegs

import (
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
)

func formatConnectionsToLegTrip(
	yyyymmdd uint,
	timezoneUTCDeltasecs int,
	legConnections []*dbt.ConnectionVerbose,
) *RouteLeg {
	var (
		connectionFrom = legConnections[0]
		connectionTo   = legConnections[len(legConnections)-1]
		timeFrom       = utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, connectionFrom.FromStopDRUTCTime)
		timeTo         = utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, connectionTo.ToStopDRUTCTime)
	)
	return &RouteLeg{
		LegType:           "trip",
		LegDuration:       timeTo.Sub(timeFrom).String(),
		LegFromCoords:     [2]float64{connectionFrom.FromStopLat, connectionFrom.FromStopLon},
		LegToCoords:       [2]float64{connectionTo.ToStopLat, connectionTo.ToStopLon},
		LegBeginTime:      timeFrom,
		LegEndTime:        timeTo,
		TripRouteHeadsign: connectionFrom.TripHeadsign,
		TripRoute:         coalesce(connectionFrom.RouteShortName, connectionFrom.RouteLongName),
		TripFrom:          &connectionFrom.FromStopName,
		TripFromStopUID:   &connectionFrom.FromStopParentUID,
		TripTo:            &connectionTo.ToStopName,
		TripToStopUID:     &connectionTo.ToStopParentUID,
		TripAgencyID:      connectionTo.AgencyID,
		TripFeedID:        &connectionTo.FeedID,
		TripStops:         ptr(FormatLegsStopDetails(yyyymmdd, timezoneUTCDeltasecs, legConnections)),
	}
}

func FormatLegsStopDetails(
	yyyymmdd uint,
	timezoneUTCDeltasecs int,
	legConnections []*dbt.ConnectionVerbose,
) []*RouteStopDetails {
	m := []*RouteStopDetails{}
	for j, c := range legConnections {
		m = append(m, &RouteStopDetails{
			Time:    utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, c.FromStopDRUTCTime),
			Name:    c.FromStopName,
			Coords:  [2]float64{c.FromStopLat, c.FromStopLon},
			ConnOID: c.ConnOID,
		})
		if j == len(legConnections)-1 {
			m = append(m, &RouteStopDetails{
				Time:    utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(yyyymmdd, timezoneUTCDeltasecs, c.ToStopDRUTCTime),
				Name:    c.ToStopName,
				Coords:  [2]float64{c.ToStopLat, c.ToStopLon},
				ConnOID: c.ConnOID,
			})
		}
	}
	return m
}
